function draw(position) % draw the quadrotor in 3d during simulation
%#codegen

global old_position;
global index_view;
global quad;

x=position(1);
y=position(2);
z=position(3);
phi=position(4);
theta=position(5);
psi=position(6);
time=position(7);

if time==0            % first times  (while time = 0)
    
    if index_view ~= 0    % just the very first time
        
        % initialize the figure
        screen = get(0,'screensize');
        visual = figure(1);
        set(visual,'position',[2 65 screen(3)-4 screen(4)-170]);
        clf(visual);
        hold on;
        
        cameratoolbar('show');
        axis vis3d;
        view(3);
        zoom(0.6);
        
        % delete these 2 for more speed
        set(gcf,'menubar','figure','renderer','opengl');
        set(gca,'Visible','On','Box','On','XGrid', 'on','YGrid', 'on','ZGrid', 'on','projection','perspective');    
        
        % draw fixed frame reference
        line([0,0.5],[0,0],[0,0],'linewidth',2,'color','red');
        line([0,0],[0,0.5],[0,0],'linewidth',2,'color','black');
        line([0,0],[0,0],[0,0.5],'linewidth',2,'color','green');
        line([-1,1],[1,1],[0,0],'linewidth',2,'color','black');
        line([-1,1],[-1,-1],[0,0],'linewidth',2,'color','black');
        line([1,1],[-1,1],[0,0],'linewidth',2,'color','black');
        line([-1,-1],[-1,1],[0,0],'linewidth',2,'color','black');
        
        text(0.6,0,0,'X','fontsize',13);
        text(0,0.6,0,'Y','fontsize',13);
        text(0,0,0.6,'Z','fontsize',13);        
        
    end
    index_view =0;     
    
end

if index_view<time;  % repeat this routine just every 0.1 s
    
    index_view = index_view + 0.1;
    
    if index_view > 0.1;  % not the first time
     
        % delete the quadrotor drawing in the old position
        drawnow;
        delete(quad.a);
        delete(quad.b);
        delete(quad.c);
        delete(quad.d);
        delete(quad.e);
        delete(quad.f);    
        line([old_position(1),x],[old_position(2),y],[old_position(3),z],'linewidth',1,'color','yellow');
    end

% rotation matrix
rot=[cos(psi)*cos(theta), -sin(psi)*cos(phi)+cos(psi)*sin(theta)*sin(phi), sin(psi)*sin(phi)+cos(psi)*sin(theta)*cos(phi);...
     sin(psi)*cos(theta),  cos(psi)*cos(phi)+sin(psi)*sin(theta)*sin(phi), -cos(psi)*sin(phi)+sin(psi)*sin(theta)*cos(phi);...
     -sin(theta),         cos(theta)*sin(phi),                             cos(theta)*cos(phi)];

% quadrotor sketch
circ_x=[0.15 0.1 0 -0.1 -0.15 -0.1 0 0.1 0.15];
circ_y=[0 0.1 0.15 0.1 0 -0.1 -0.15 -0.1 0];
circ_z=[0 0 0 0 0 0 0 0 0];

% draw the quadrotor
points=[-0.25 0.25;0 0;0 0];
quad.a=line(x+rot(1,:)*points,y+rot(2,:)*points,z+rot(3,:)*points,'linewidth',2,'color','black');
points=[0 0;-0.25 0.25;0 0];
quad.b=line(x+rot(1,:)*points,y+rot(2,:)*points,z+rot(3,:)*points,'linewidth',2,'color','black');
points=[circ_x+0.25;circ_y;circ_z];
quad.c=line(x+rot(1,:)*points,y+rot(2,:)*points,z+rot(3,:)*points,'linewidth',2,'color','red');
points=[circ_x;circ_y+0.25;circ_z];
quad.d=line(x+rot(1,:)*points,y+rot(2,:)*points,z+rot(3,:)*points,'linewidth',2,'color','blue');
points=[circ_x-0.25;circ_y;circ_z];
quad.e=line(x+rot(1,:)*points,y+rot(2,:)*points,z+rot(3,:)*points,'linewidth',2,'color','blue');
points=[circ_x;circ_y-0.25;circ_z];
quad.f=line(x+rot(1,:)*points,y+rot(2,:)*points,z+rot(3,:)*points,'linewidth',2,'color','blue');

old_position=[x,y,z];  % save the current position for the path plot

% set the camera position and target
camtarget_x=position(1)/2;
camtarget_y=position(2)/2;
camtarget_z=position(3)/2;
campos_x=(camtarget_x/2+camtarget_y)*6-2;
campos_y=(camtarget_y/2-camtarget_x)*6-1;
campos_z=camtarget_z+sqrt(campos_x^2+campos_y^2)/6+3;

camtarget([camtarget_x,camtarget_y,camtarget_z]);     
campos([campos_x,campos_y,campos_z]);

end
